import react, { useRef } from 'react';

import {
  IonButton,
  IonButtons,
  IonContent,
  IonIcon,
  IonItem,
  IonLabel,
  IonList,
  IonModal,
  IonRadio,
  IonRadioGroup,
  IonTitle,
  IonToolbar,
} from '@ionic/react';
import { layersOutline } from 'ionicons/icons';
import { nonFakeTileProviders } from '../map/tile-providers';
import { tileProviderAtom } from '../../App';
import i18n from '../../i18n/index';
import { useAtom } from 'jotai';

import cssDialog from './dialogs.module.css';

export interface MapChooserProperties {}

export const MapChooser: react.FC<MapChooserProperties> = (
  props: MapChooserProperties
) => {
  const modal = useRef<HTMLIonModalElement>(null);

  const dismiss = () => {
    modal.current?.dismiss();
  };

  const [tileProvider, setTileProvider] = useAtom(tileProviderAtom);

  const changeHandler = (event: any) => {
    setTileProvider(event.detail.value);
    dismiss();
  };

  return (
    <>
      <IonButton id='open-TileServerChooser'>
        <IonIcon slot='icon-only' icon={layersOutline} />
      </IonButton>
      <IonModal
        trigger='open-TileServerChooser'
        ref={modal}
        className={cssDialog.modal}
      >
        <IonToolbar>
          <IonTitle>{i18n.mapChooser.chooseYourMap}</IonTitle>
          <IonButtons slot='end'>
            <IonButton onClick={() => dismiss()}>{i18n.common.close}</IonButton>
          </IonButtons>
        </IonToolbar>
        <IonContent>
          <IonList>
            <IonRadioGroup value={tileProvider} onIonChange={changeHandler}>
              {Object.keys(nonFakeTileProviders).map((provider) => {
                return (
                  <IonItem key={provider}>
                    <IonLabel> {nonFakeTileProviders[provider].name}</IonLabel>
                    <IonRadio slot='start' value={provider} />
                  </IonItem>
                );
              })}
            </IonRadioGroup>
          </IonList>
        </IonContent>
      </IonModal>
    </>
  );
};

export default MapChooser;
